Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1164)

Unified Diff: runtime/bin/eventhandler.cc

Issue 359673002: - Remove Dart_ReceivePortGetId, Dart_GetReceivePort and Dart_PostMessage. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | runtime/bin/eventhandler_patch.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/bin/eventhandler.cc
===================================================================
--- runtime/bin/eventhandler.cc (revision 37823)
+++ runtime/bin/eventhandler.cc (working copy)
@@ -92,11 +92,11 @@
} else {
id = Socket::GetSocketIdNativeField(sender);
}
// Get the id out of the receive port. If the handle is not a receive port
// we will get an error and propagate that out.
Dart_Handle handle = Dart_GetNativeArgument(args, 1);
Dart_Port dart_port;
- handle = Dart_ReceivePortGetId(handle, &dart_port);
+ handle = Dart_SendPortGetId(handle, &dart_port);
if (Dart_IsError(handle)) {
Dart_PropagateError(handle);
UNREACHABLE();
@@ -92,11 +92,11 @@
id = Socket::GetSocketIdNativeField(sender);
}
- // Get the id out of the receive port. If the handle is not a receive port
+ // Get the id out of the send port. If the handle is not a send port
// we will get an error and propagate that out.
Dart_Handle handle = Dart_GetNativeArgument(args, 1);
« no previous file with comments | « no previous file | runtime/bin/eventhandler_patch.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698